@@ -2,9 +2,12 @@
 
 /**
   * SquirrelMail Compatibility Plugin
-  * Copyright (C) 2004-2007 Paul Lesneiwski <paul@squirrelmail.org>
+  * Copyright (C) 2004-2007 Paul Lesniewski <paul@squirrelmail.org>
   * This program is licensed under GPL. See COPYING for details
   *
+  * SquirrelMail developers, see below under "SQUIRRELMAIL DEVELOPER 
+  * NOTES" for information about how the include files are maintained
+  *
   */
 
 
@@ -107,8 +110,13 @@
       if (function_exists('check_sm_version'))
          return check_sm_version($a, $b, $c);
 
-      global $version;
+      if (is_defined('SM_VERSION'))
+         $version = SM_VERSION;
+      else
+         global $version;
+
       list($aa, $bb, $cc) = preg_split('/\./', $version, 3);
+      $cc = intval($cc);
 
       if(!is_numeric($cc))
          list($cc, $info) = explode(' ', $cc, 2);
@@ -130,44 +138,113 @@
 
       global $compatibility_sm_path;
 
-      // this array should be updated with every release of SquirrelMail,
-      // along with adding needed directories in the includes for this plugin
+      // SQUIRRELMAIL DEVELOPER NOTES
       //
-      // order in this array is significant, please keep newest releases
+      // The array below should be updated with every release of 
+      // SquirrelMail, along with adding needed directories in the 
+      // includes for this plugin.
+      //
+      // Code that was added as of a certain version should be put 
+      // in the include file in the directory corresponding to that 
+      // same version number in order to make it available to older
+      // versions.  When including files here, that file will be
+      // included for all versions prior.
+      //
+      // If some code was added to the newest codebase for two different
+      // release series, for example, a function called "sq_new_function()"
+      // that was added in both 1.4.10 as well as 1.5.2, please add 
+      // the function to only the higher version (1.5.2 in this case),
+      // and add additional logic to the way it is included:
+      //
+      //    if ((!compatibility_check_sm_version(1, 4, 10)
+      //      || (compatibility_check_sm_version(1, 5, 0) 
+      //     && !compatibility_check_sm_version(1, 5, 2)))
+      //     && !function_exists('sq_new_function'))
+      //    {
+      //    function sq_new_function()
+      //    {
+      //       echo "HELLO WORLD";
+      //    }
+      //    }
+      //
+      // NOTE: In-between version includes should simply be put in the
+      //       lowest version include file for the new release series
+      //       (e.g., anything in the 1.5.0 include file will be loaded
+      //       for all 1.4.x versions, and of course, not for 1.5.0).
+      //       The following in-between include file system is thus not 
+      //       needed, but leaving code and documentation about how it 
+      //       works just for edification:
+      //
+      // In-between include directories should be named as such:
+      // "1.4.x-to-1.5.0" where the latter version string must 
+      // correspond to a real SquirrelMail version and the versions 
+      // must be separated by the string "-to-"
+      //
+      // Order in this array is significant, please keep newest releases
       // at top of this list, ordered downward from there...
       //
-      // these have to be hard-coded since there is no way to know if this
+      // These have to be hard-coded since there is no way to know if this
       // plugin is being used in series 1.2.x, 1.3.x, 1.4.x, 1.5.x, etc.
       //
       $compatibility_versions = array(
          '1.5.2', '1.5.1', '1.5.0',
-         '1.4.10', '1.4.9', '1.4.8', '1.4.7', 
+         // in-between includes not needed:
+         //'1.4.x-to-1.5.0',
+         '1.4.11', '1.4.10', '1.4.9', '1.4.8', '1.4.7', 
          '1.4.6', '1.4.5', '1.4.4', '1.4.3', '1.4.2', '1.4.1', '1.4.0',
          // skipping 1.3.x, not supported for now
+         // in-between includes not needed:
+         //'1.2.x-to-1.4.0',
          '1.2.11', '1.2.10', '1.2.9', '1.2.8', '1.2.7',
          // if you are running anything older than this, I feel really, really sorry for you
                                      );
 
-      $is_first = TRUE;
-      foreach ($compatibility_versions as $version_string)
+
+      // loop through all versions in our list, including files
+      // for all versions newer than the one being run here and now
+      //
+      $last_csv_version_string = '';
+      $last_version_string = '';
+      for ($count = 0; !empty($compatibility_versions[$count]); $count++)
       {
 
-         $csv_version_string = str_replace('.', ', ', $version_string);
+         $version_string = $compatibility_versions[$count];
 
-         if ($is_first)
+
+/* ----- see above; in-between includes not needed...
+         // in-between version files: set version string to the higher
+         // version so that all versions in the release series below
+         // it will see it
+         //
+         if (($pos = strpos($version_string, '-to-')) !== FALSE)
+            $csv_version_string = str_replace('.', ', ', substr($version_string, $pos + 4));
+
+
+         // normal conversion to CSV values
+         //
+         else
+----- */
+            $csv_version_string = str_replace('.', ', ', $version_string);
+
+
+         if ($count == 0)
          {
             eval('if (compatibility_check_sm_version(' . $csv_version_string . ')) return;');
-            $is_first = FALSE;
+            $last_csv_version_string = $csv_version_string;
+            $last_version_string = $version_string;
             continue;
          }
 
 
          if (eval('if (file_exists($compatibility_sm_path . \'plugins/compatibility/includes/'
-              . $version_string . '/global.php\')) include_once($compatibility_sm_path . \'plugins/compatibility/includes/'
-              . $version_string . '/global.php\'); if (compatibility_check_sm_version('
+              . $last_version_string . '/global.php\')) include_once($compatibility_sm_path . \'plugins/compatibility/includes/'
+              . $last_version_string . '/global.php\'); if (compatibility_check_sm_version('
               . $csv_version_string . ')) return TRUE;'))
             return;
 
+         $last_csv_version_string = $csv_version_string;
+         $last_version_string = $version_string;
+
       }
 
    }
