@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Compatibility Plugin
-  * Copyright (c) 2004-2007 Paul Lesneiwski <paul@squirrelmail.org>
+  * Copyright (c) 2004-2007 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -21,10 +21,19 @@ function compatibility_info()
 
    return array(
                  'english_name' => 'Compatibility',
-                 'version' => '2.0.6',
-                 'required_sm_vesion' => '1.0',
+                 'version' => '2.0.7',
+                 'required_sm_version' => '1.0',
                  'requires_configuration' => 0,
-                 'requires_source_patch' => 0,
+                 'requires_source_patch' => 2,
+                 'required_plugins' => array(),
+                 'per_version_requirements' => array(
+                    '1.5.1' => array(
+                       'requires_source_patch' => 0,
+                    ),
+                    '1.0.0' => array(
+                       'requires_source_patch' => 1,
+                    ),
+                 ),
                  'summary' => 'Allows plugins to remain compatible with all versions of SquirrelMail.',
                  'details' => 'This plugin allows any other plugin access to the functions and special variables needed to make it backward (and forward) compatible with most versions of SM in wide use.  This eliminates the need for duplication of certain functions throughout many plugins.  It also provides functionality that helps check that plugins have been installed and set up correctly.',
                );
